(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     59698,       1084]
NotebookOptionsPosition[     59873,       1070]
NotebookOutlinePosition[     60591,       1095]
CellTagsIndexPosition[     60548,       1092]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Strain\n",
 StyleBox["Qingchang Liu, Baoxing Xu and Marek-Jerzy Pindera\nUniversity of \
Virginia, 2018-01-30",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center,
 ExpressionUUID -> "1f0b3856-036c-4559-ac86-a359a58bd3e2"],

Cell["\<\
This module presents the definition of strain.

Strains are measures of deformation represented by displacements between \
particles in the body relative to a reference configuration. They are \
classified as either normal or shear. Normal strains represent changes in \
lengths of line elements oriented along the three axes associated with an \
infinitesimal cube and hence are perpendicular to the cube\[CloseCurlyQuote]s \
faces. Therefore they also represent volumetric changes. Shear strains \
represent changes in the angles of mutually orthogonal line elements in the \
three planes x-y, y-z and x-z of an infinitesimal cube. Therefore they also \
represent cube\[CloseCurlyQuote]s distortion.

There are three normal strains and six shear strains, but only three of the \
six shear strains are independent because shear strains are symmetric. These \
strains comprise the three-dimensional strain tensor in analogy with the \
stress tensor and may be represented using the same matrix notation. \
\>", "Text",
 ExpressionUUID -> "50edfe98-c88f-49cd-b9d2-e658b33bf322"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`opa2$$ = 1, $CellContext`P$$ = 
    0, $CellContext`V$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`opa2$$], 1, 
       Row[{"Types of Strain", 
         Spacer[51]}]}, {1 -> "Normal", 0 -> "Shear"}}, {{
       Hold[$CellContext`P$$], 0, 
       Row[{"Loading P", 
         Spacer[80]}]}, -5, 5}, {{
       Hold[$CellContext`V$$], 0, 
       Row[{"Loading V", 
         Spacer[79]}]}, -5, 5}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          PaneSelector[{1 -> Column[{
               Manipulate`Place[2]}], 0 -> Column[{
               Manipulate`Place[3]}]}, 
           Dynamic[$CellContext`opa2$$]]}, {
          Row[{
            Spacer[10], 
            Dynamic[
             
             If[$CellContext`opa2$$ == 
              1, $CellContext`temp1, $CellContext`temp2]]}]}, {
          Row[{
            Spacer[10], 
            Dynamic[
             If[$CellContext`opa2$$ < 1, $CellContext`temp3, 
              Invisible[$CellContext`temp3]]]}]}, {
          Row[{
            Spacer[10], 
            Dynamic[
             If[$CellContext`opa2$$ < 1, $CellContext`temp4, 
              Invisible[$CellContext`temp4]]]}]}, {
          Row[{
            Spacer[10], 
            Dynamic[
             If[$CellContext`opa2$$ < 1, $CellContext`temp5, 
              Invisible[$CellContext`temp5]]]}]}}, Alignment -> Left, 
        Spacings -> {Automatic, 1.5}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {434., {210., 218.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`opa2$176369$$ = False, $CellContext`P$176370$$ = 
    0, $CellContext`V$176371$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`opa2$$ = 1, $CellContext`P$$ = 
        0, $CellContext`V$$ = 0}, "ControllerVariables" :> {
        Hold[$CellContext`opa2$$, $CellContext`opa2$176369$$, False], 
        Hold[$CellContext`P$$, $CellContext`P$176370$$, 0], 
        Hold[$CellContext`V$$, $CellContext`V$176371$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`size$, 
         E$, $CellContext`G$, $CellContext`A$, $CellContext`L$, \
$CellContext`W$, $CellContext`Lp$, $CellContext`Wp$, $CellContext`phi$, \
$CellContext`miu$, $CellContext`delta$, $CellContext`Ax$, $CellContext`Ay$, \
$CellContext`Bx$, $CellContext`By$, $CellContext`Cx$, $CellContext`Cy$, \
$CellContext`Dx$, $CellContext`Dy$, $CellContext`dwf0$, $CellContext`dwf1$, \
$CellContext`dwf2$, $CellContext`dwf3$, $CellContext`dwf4$, \
$CellContext`dwf5$, $CellContext`dwf6$, $CellContext`dwf7$, \
$CellContext`dwf8$, $CellContext`dwf9$, $CellContext`dw1$}, \
$CellContext`size$ = 20; 
        E$ = 10; $CellContext`G$ = 15; $CellContext`A$ = 1; $CellContext`L$ = 
         15; $CellContext`W$ = $CellContext`L$; $CellContext`miu$ = 
         0.4; $CellContext`delta$ = $CellContext`P$$ (($CellContext`L$/
            E$)/$CellContext`A$); $CellContext`Lp$ = $CellContext`L$ + \
$CellContext`delta$; $CellContext`Wp$ = $CellContext`W$ (
           1 - $CellContext`miu$ ($CellContext`delta$/$CellContext`L$)); \
$CellContext`phi$ = $CellContext`V$$/$CellContext`G$; $CellContext`Ax$ = \
(-$CellContext`L$)/2; $CellContext`Ay$ = (-$CellContext`L$)/
          2; $CellContext`Bx$ = $CellContext`Ax$ + ($CellContext`L$ 
            Sqrt[1 + $CellContext`phi$ $CellContext`phi$]) 
           Cos[$CellContext`phi$]; $CellContext`By$ = $CellContext`Ay$ + \
($CellContext`L$ Sqrt[1 + $CellContext`phi$ $CellContext`phi$]) 
           Sin[$CellContext`phi$]; $CellContext`Cx$ = $CellContext`Bx$ + \
($CellContext`L$ Sqrt[1 + $CellContext`phi$ $CellContext`phi$]) 
           Cos[Pi/2 - $CellContext`phi$]; $CellContext`Cy$ = $CellContext`By$ + \
($CellContext`L$ Sqrt[1 + $CellContext`phi$ $CellContext`phi$]) 
           Sin[Pi/2 - $CellContext`phi$]; $CellContext`Dx$ = $CellContext`Ax$ + \
($CellContext`L$ Sqrt[1 + $CellContext`phi$ $CellContext`phi$]) 
           Cos[Pi/2 - $CellContext`phi$]; $CellContext`Dy$ = $CellContext`Ay$ + \
($CellContext`L$ Sqrt[1 + $CellContext`phi$ $CellContext`phi$]) 
           Sin[Pi/2 - $CellContext`phi$]; If[Abs[$CellContext`P$$] > 0, 
          
          If[$CellContext`P$$ > 0, $CellContext`temp1 = 
           Row[{"\!\(\*\nStyleBox[SubscriptBox[\"\[CurlyEpsilon]\", \"x\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[FractionBox[\n  RowBox[{\n \
  RowBox[{\n    StyleBox[\"(\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"], \n    RowBox[{SubscriptBox[\n      StyleBox[\"l\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"], \"x\"], \"+\", \n     \
StyleBox[SubscriptBox[\n       StyleBox[\n        \
RowBox[{\"\[CapitalDelta]\", \n         StyleBox[\n          StyleBox[\"l\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"],\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]}]], \"x\"],\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]}], \n    StyleBox[\")\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]}], \n   StyleBox[\"-\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"], SubscriptBox[\n    StyleBox[\"l\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"], \"x\"]}], SubscriptBox[\n   \
StyleBox[\"l\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"], \"x\"]],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[FractionBox[\n  StyleBox[SubscriptBox[\n    StyleBox[\n\
     RowBox[{\"\[CapitalDelta]\", \n      StyleBox[\"l\",\nFontWeight->\"Bold\
\",\nFontSlant->\"Italic\"]}]], \"x\"],\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"], SubscriptBox[\n   StyleBox[\"l\",\nFontWeight->\"Bold\
\",\nFontSlant->\"Italic\"], \"x\"]],\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\">\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"0\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
1.]]\)"}], $CellContext`temp1 = 
           Row[{"\!\(\*\nStyleBox[SubscriptBox[\"\[CurlyEpsilon]\", \"x\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[FractionBox[\n  RowBox[{\n \
  RowBox[{\n    StyleBox[\"(\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"], \n    RowBox[{SubscriptBox[\n      StyleBox[\"l\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"], \"x\"], \"+\", \n     \
StyleBox[SubscriptBox[\n       StyleBox[\n        \
RowBox[{\"\[CapitalDelta]\", \n         StyleBox[\"l\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]}]], \"x\"],\nFontWeight->\"Bold\
\",\nFontSlant->\"Italic\"]}], \n    StyleBox[\")\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]}], \n   StyleBox[\"-\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"], SubscriptBox[\n    StyleBox[\"l\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"], \"x\"]}], SubscriptBox[\n   \
StyleBox[\"l\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"], \"x\"]],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[FractionBox[\n  StyleBox[SubscriptBox[\n    StyleBox[\n\
     RowBox[{\"\[CapitalDelta]\", \n      StyleBox[\"l\",\nFontWeight->\"Bold\
\",\nFontSlant->\"Italic\"]}]], \"x\"],\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"], SubscriptBox[\n   StyleBox[\"l\",\nFontWeight->\"Bold\
\",\nFontSlant->\"Italic\"], \"x\"]],\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"<\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"0\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
1.]]\)"}]], $CellContext`temp1 = 
          Row[{"\!\(\*\nStyleBox[SubscriptBox[\"\[CurlyEpsilon]\", \"x\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\"0\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0., 0., 1.]]\)"}]]; 
        If[Abs[$CellContext`V$$] > 0, $CellContext`temp2 = 
          Row[{"\!\(\*\nStyleBox[\"tan\[Alpha]\",\nFontFamily->\"Times New \
Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[FractionBox[\n  StyleBox[\"\[CapitalDelta]v\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"], SubscriptBox[\"l\", \"x\"]],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\",\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"tan\[Beta]\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Plain\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[FractionBox[\n  StyleBox[\"\[CapitalDelta]u\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"], SubscriptBox[\"l\", \"y\"]],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\",\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., \
0.]]\)"}], $CellContext`temp2 = 
          Row[{"\!\(\*\nStyleBox[\"The\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\
\*\nStyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"shear\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"strain\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"at\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"point\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"A\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"is\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\":\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\
\"\[Gamma]\",\nFontSize->14,\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., \
0., 0.]], \n  StyleBox[\"xy\",\nFontSize->9,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]],\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\
\"|\",\nFontFamily->\"Times New Roman\",\nFontSize->14], \"A\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"0\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[1., 0., 0.]]\)"}]]; 
        If[Abs[$CellContext`V$$] > 0, $CellContext`temp3 = 
          Row[{"\!\(\*\nStyleBox[\"If\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\
\*\nStyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"\[CapitalDelta]u\",\nFontFamily->\"Times New \
Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"\[LessLess]\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[SubscriptBox[\"l\", \"y\"],\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"and\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\
\[CapitalDelta]v\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"\[LessLess]\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\
\*\nStyleBox[SubscriptBox[\"l\", \"x\"],\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\",\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"then\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"tan\[Alpha]\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"=\
\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Alpha]\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"and\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"tan\[Beta]\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"=\
\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Beta]\",\nFontFamily->\
\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\".\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)"}], $CellContext`temp3 = Row[{""}]]; 
        If[Abs[$CellContext`V$$] > 0, $CellContext`temp4 = 
          Row[{"\!\(\*\nStyleBox[\"The\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\
\*\nStyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"shear\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"strain\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"at\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"point\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"A\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"is\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\":\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontSize->14]\)"}], $CellContext`temp4 = 
          Row[{""}]]; If[Abs[$CellContext`V$$] > 0, 
          
          If[$CellContext`V$$ > 0, $CellContext`temp5 = 
           Row[{"\!\(\*\nStyleBox[\" \",\nFontFamily->\"Times New Roman\",\n\
FontSize->14]\)\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\"\[Gamma]\",\n\
FontSize->14,\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]], \n  \
StyleBox[\"xy\",\nFontSize->9,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]],\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\
\"|\",\nFontFamily->\"Times New Roman\",\nFontSize->14], \"A\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[FractionBox[\n  RowBox[{\n   StyleBox[\" \",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]], \"\[Pi]\"}], \"2\"],\nFontFamily->\"Times \
New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., \
0., 0.]]\)\!\(\*\nStyleBox[\"-\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"[\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[FractionBox[\n  RowBox[{\n   StyleBox[\" \",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]], \"\[Pi]\"}], \"2\"],\
\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"-\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"(\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Alpha]\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"+\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Beta]\",\nFontFamily->\
\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\")\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Alpha]\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"+\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Beta]\",\nFontFamily->\
\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\">\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"0.\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)"}], $CellContext`temp5 = 
           Row[{"\!\(\*\nStyleBox[\" \",\nFontFamily->\"Times New Roman\",\n\
FontSize->14]\)\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\"\[Gamma]\",\n\
FontSize->14,\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]], \n  \
StyleBox[\"xy\",\nFontSize->9,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]],\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\
\"|\",\nFontFamily->\"Times New Roman\",\nFontSize->14], \"A\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[FractionBox[\n  RowBox[{\n   StyleBox[\" \",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]], \"\[Pi]\"}], \"2\"],\nFontFamily->\"Times \
New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., \
0., 0.]]\)\!\(\*\nStyleBox[\"-\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"[\",\nFontFamily->\"Times New Roman\",\n\
FontSize->14,\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[FractionBox[\n  RowBox[{\n   StyleBox[\" \",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]], \"\[Pi]\"}], \"2\"],\
\nFontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"-\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"(\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Alpha]\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"+\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Beta]\",\nFontFamily->\
\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\")\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Alpha]\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"+\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Beta]\",\nFontFamily->\
\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"<\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"0\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)"}]], $CellContext`temp5 = 
          Row[{""}]]; $CellContext`dwf0$ = {
           Opacity[$CellContext`opa2$$], 
           Dashing[{}], 
           Thickness[0.004], 
           Arrowheads[0.04], 
           
           Line[{{(-$CellContext`L$)/2, 
              0.6 $CellContext`size$}, {(-$CellContext`L$)/2, 
              0.7 $CellContext`size$}}], 
           
           Arrow[{{(-$CellContext`L$)/2, 0.65 $CellContext`size$}, {
             0, 0.65 $CellContext`size$}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {$CellContext`L$/40, 
             0.65 $CellContext`size$}]}; $CellContext`dwf1$ = {
           Opacity[$CellContext`opa2$$], 
           Lighter[Blue], 
           If[Abs[$CellContext`delta$] > 0, 
            
            Rectangle[{(-$CellContext`L$)/2, (-$CellContext`Wp$)/
              2}, {$CellContext`Lp$/2, $CellContext`Wp$/2}]], 
           Opacity[$CellContext`opa2$$ 0.5], 
           Lighter[Green], 
           
           Rectangle[{(-$CellContext`L$)/2, (-$CellContext`W$)/
             2}, {$CellContext`L$/2, $CellContext`W$/2}]}; $CellContext`dwf2$ = {
           Opacity[$CellContext`opa2$$], Red, 
           Thickness[0.008], 
           Arrowheads[0.06], 
           If[$CellContext`P$$ > 0, 
            
            Arrow[{{$CellContext`Lp$/2, 
               0}, {$CellContext`Lp$/2 + $CellContext`P$$ 0.9, 0}}], 
            
            Arrow[{{$CellContext`Lp$/2 - $CellContext`P$$ 0.9, 
               0}, {$CellContext`Lp$/2, 0}}]], 
           If[Abs[$CellContext`P$$] > 0, 
            If[$CellContext`P$$ > 0, 
             Text[
             "\!\(\*\nStyleBox[\"P\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {
              0.5 $CellContext`Lp$ + $CellContext`P$$ 0.55, 
               0.05 $CellContext`W$}], 
             Text[
             "\!\(\*\nStyleBox[\"P\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {
              0.5 $CellContext`Lp$ - $CellContext`P$$ 0.55, 
               0.05 $CellContext`W$}]]]}; $CellContext`dwf3$ = {
           Opacity[$CellContext`opa2$$], 
           Arrowheads[0.03], 
           If[Abs[$CellContext`delta$] > 0, 
            
            Line[{{$CellContext`L$/2, (-$CellContext`L$)/2}, {$CellContext`L$/
               2, (-$CellContext`L$)/2 - 0.3 $CellContext`W$}}]], 
           If[Abs[$CellContext`delta$] > 0, 
            
            Line[{{(-$CellContext`L$)/2, (-$CellContext`W$)/
               2}, {(-$CellContext`L$)/2, (-$CellContext`W$)/2 - 
               0.3 $CellContext`W$}}]], 
           If[Abs[$CellContext`delta$] > 0, 
            
            Arrow[{{(-$CellContext`L$)/2, (-$CellContext`W$)/2 - 
               0.25 $CellContext`W$}, {$CellContext`L$/
               2, (-$CellContext`W$)/2 - 0.25 $CellContext`W$}}]], 
           If[Abs[$CellContext`delta$] > 0, 
            
            Arrow[{{$CellContext`L$/2, (-$CellContext`W$)/2 - 
               0.25 $CellContext`W$}, {(-$CellContext`L$)/
               2, (-$CellContext`W$)/2 - 0.25 $CellContext`W$}}]], 
           If[Abs[$CellContext`delta$] > 0, 
            Text[
            "\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\"l\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"], \"x\"],\nFontFamily->\"Times \
New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", {0, (-0.82) $CellContext`W$}]], 
           If[Abs[$CellContext`delta$] > 0, 
            
            Line[{{$CellContext`Lp$/2, (-$CellContext`Wp$)/
               2}, {$CellContext`Lp$/
               2, (-$CellContext`W$)/2 - $CellContext`W$/6}}]], 
           
           Arrow[{{$CellContext`L$/2, (-$CellContext`W$)/2 - $CellContext`W$/
              8}, {$CellContext`Lp$/2, (-$CellContext`W$)/2 - $CellContext`W$/
              8}}], 
           
           Arrow[{{$CellContext`Lp$/2, (-$CellContext`W$)/2 - $CellContext`W$/
              8}, {$CellContext`L$/2, (-$CellContext`W$)/2 - $CellContext`W$/
              8}}], 
           If[Abs[$CellContext`delta$] > 0, 
            Text[
            "\!\(\*\nStyleBox[SubscriptBox[\"\[CapitalDelta]l\", \"x\"],\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)", {$CellContext`L$/
               2 + ($CellContext`Lp$/2 - $CellContext`L$/2)/
               2, (-0.7) $CellContext`W$}]], 
           
           Line[{{$CellContext`Lp$/2, $CellContext`Wp$/2}, {$CellContext`Lp$/
              2, 0.7 $CellContext`W$}}], 
           
           Line[{{(-$CellContext`L$)/2, $CellContext`Wp$/
              2}, {(-$CellContext`L$)/2, 0.7 $CellContext`W$}}], 
           
           Arrow[{{(-$CellContext`L$)/2, 
              0.65 $CellContext`W$}, {$CellContext`Lp$/2, 
              0.65 $CellContext`W$}}], 
           
           Arrow[{{$CellContext`Lp$/2, 
              0.65 $CellContext`W$}, {(-$CellContext`L$)/2, 
              0.65 $CellContext`W$}}], 
           If[Abs[$CellContext`delta$] > 0, 
            Text[
            "\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\"l\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"], \"x\"],\nFontFamily->\"Times \
New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"+\",\n\
FontFamily->\"Times New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\
\[CapitalDelta]\",\nFontFamily->\"Times New Roman\",\nFontSize->14,\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\"l\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"], \"x\"],\nFontFamily->\"Times \
New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", {((-$CellContext`L$)/
                2 + $CellContext`Lp$/2)/2, 0.7 $CellContext`W$}], 
            Text[
            "\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\"l\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"], \"x\"],\nFontFamily->\"Times \
New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", {
             0, 0.7 $CellContext`W$}]]}; $CellContext`dwf4$ = {
           Opacity[(1 - $CellContext`opa2$$) 0.5], 
           Lighter[Green], 
           
           Rectangle[{(-$CellContext`L$)/2, (-$CellContext`L$)/
             2}, {$CellContext`L$/2, $CellContext`L$/2}], Black, 
           Text[
           "\!\(\*\nStyleBox[\"A\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {(-$CellContext`L$)/
              2 - $CellContext`L$/20, (-$CellContext`L$)/2}], 
           Text[
           "\!\(\*\nStyleBox[\"B\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {$CellContext`L$/
              2 + $CellContext`L$/20, (-$CellContext`L$)/2 + $CellContext`L$/
              20}], 
           Text[
           "\!\(\*\nStyleBox[\"C\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\"]\)", {$CellContext`L$/2 + $CellContext`L$/
              20, $CellContext`L$/2 + $CellContext`L$/20}], 
           Text[
           "\!\(\*\nStyleBox[\"D\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {(-$CellContext`L$)/
              2 + $CellContext`L$/20, $CellContext`L$/2 + $CellContext`L$/
              20}], 
           Thickness[0.001], 
           Arrowheads[0.02], 
           
           Arrow[{{(-$CellContext`L$)/2, (-$CellContext`L$)/
              2}, {$CellContext`L$/2 + $CellContext`L$/5, (-$CellContext`L$)/
              2}}], 
           
           Arrow[{{(-$CellContext`L$)/2, (-$CellContext`L$)/
              2}, {(-$CellContext`L$)/
              2, $CellContext`L$/2 + $CellContext`L$/5}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {$CellContext`L$/
              2 + $CellContext`L$/5, (-$CellContext`L$)/2 - $CellContext`L$/
             20}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {(-$CellContext`L$)/
              2 - $CellContext`L$/
             20, $CellContext`L$/2 + $CellContext`L$/5}]}; $CellContext`dwf5$ = {
           Opacity[(1 - $CellContext`opa2$$) 0.8], 
           Lighter[Red], 
           If[Abs[$CellContext`phi$] > 0, 
            
            Parallelogram[{$CellContext`Ax$, $CellContext`Ay$}, \
{{$CellContext`Bx$ - $CellContext`Ax$, $CellContext`By$ - $CellContext`Ay$}, \
{$CellContext`Dx$ - $CellContext`Ax$, $CellContext`Dy$ - \
$CellContext`Ay$}}]]}; $CellContext`dwf6$ = {
           Opacity[1 - $CellContext`opa2$$], 
           Dashing[{}], 
           Thickness[0.001], 
           Arrowheads[0.02], 
           If[Abs[$CellContext`phi$] > 0, 
            
            Arrow[{{$CellContext`Ax$, $CellContext`Ay$}, {$CellContext`Bx$ + 
               0.3 ($CellContext`Bx$ - $CellContext`Ax$), $CellContext`By$ + 
               0.3 ($CellContext`By$ - $CellContext`Ay$)}}]], 
           If[Abs[$CellContext`phi$] > 0, 
            
            Arrow[{{$CellContext`Ax$, $CellContext`Ay$}, {$CellContext`Dx$ + 
               0.3 ($CellContext`Dx$ - $CellContext`Ax$), $CellContext`Dy$ + 
               0.3 ($CellContext`Dy$ - $CellContext`Ay$)}}]], 
           If[Abs[$CellContext`phi$] > 0, 
            Text[
            "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\"'\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {$CellContext`Bx$ + 
              0.3 ($CellContext`Bx$ - $CellContext`Ax$), $CellContext`By$ + 
              0.3 ($CellContext`By$ - $CellContext`Ay$) - $CellContext`W$/
              20}]], 
           If[Abs[$CellContext`phi$] > 0, 
            Text[
            "\!\(\*\nStyleBox[\"y\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\"'\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {$CellContext`Dx$ + 
              0.3 ($CellContext`Dx$ - $CellContext`Ax$) - $CellContext`W$/
              20, $CellContext`Dy$ + 
              0.3 ($CellContext`Dy$ - $CellContext`Ay$)}]], 
           If[Abs[$CellContext`phi$] > 0, 
            Text[
            "\!\(\*\nStyleBox[\"A\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\"'\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-$CellContext`L$)/2 + $CellContext`L$/
               20, (-$CellContext`L$)/2 + $CellContext`L$/20}]], 
           If[Abs[$CellContext`phi$] > 0, 
            Text[
            "\!\(\*\nStyleBox[\"B\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\"'\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {$CellContext`Bx$ - $CellContext`L$/
              20, $CellContext`By$ + $CellContext`L$/20}]], 
           If[Abs[$CellContext`phi$] > 0, 
            Text[
            "\!\(\*\nStyleBox[\"C\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\"'\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {$CellContext`Cx$ - $CellContext`L$/
              20, $CellContext`Cy$ - $CellContext`L$/20}]], 
           If[Abs[$CellContext`phi$] > 0, 
            Text[
            "\!\(\*\nStyleBox[\"D\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\"'\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {$CellContext`Dx$ + $CellContext`L$/
               20, $CellContext`Dy$ - $CellContext`L$/20}]], 
           
           Circle[{$CellContext`Ax$, $CellContext`Ay$}, $CellContext`L$/
            3, {$CellContext`phi$, Pi/2 - $CellContext`phi$}], 
           Arrow[{{$CellContext`Ax$ + ($CellContext`L$/3) 
               Cos[$CellContext`phi$ + 
                 Pi/20], $CellContext`Ay$ + ($CellContext`L$/3) 
               Sin[$CellContext`phi$ + 
                 Pi/20]}, {$CellContext`Ax$ + ($CellContext`L$/3) 
               Cos[$CellContext`phi$], $CellContext`Ay$ + ($CellContext`L$/3) 
               Sin[$CellContext`phi$]}}], 
           
           Arrow[{{$CellContext`Ax$ + ($CellContext`L$/3) 
               Cos[Pi/2 - $CellContext`phi$ - Pi/
                 20], $CellContext`Ay$ + ($CellContext`L$/3) 
               Sin[Pi/2 - $CellContext`phi$ - Pi/
                 20]}, {$CellContext`Ax$ + ($CellContext`L$/3) 
               Cos[Pi/2 - $CellContext`phi$], $CellContext`Ay$ + \
($CellContext`L$/3) Sin[Pi/2 - $CellContext`phi$]}}], 
           
           Circle[{$CellContext`Ax$, $CellContext`Ay$}, $CellContext`L$/1.5, {
            0, $CellContext`phi$}], 
           
           Arrow[{{$CellContext`Ax$ + ($CellContext`L$/1.5) 
               Cos[$CellContext`phi$/5], $CellContext`Ay$ + ($CellContext`L$/
                1.5) Sin[$CellContext`phi$/
                 5]}, {$CellContext`Ax$ + $CellContext`L$/
               1.5, $CellContext`Ay$}}], 
           
           Arrow[{{$CellContext`Ax$ + ($CellContext`L$/1.5) 
               Cos[$CellContext`phi$ - $CellContext`phi$/
                 5], $CellContext`Ay$ + ($CellContext`L$/1.5) 
               Sin[$CellContext`phi$ - $CellContext`phi$/
                 5]}, {$CellContext`Ax$ + ($CellContext`L$/1.5) 
               Cos[$CellContext`phi$], $CellContext`Ay$ + ($CellContext`L$/
                1.5) Sin[$CellContext`phi$]}}], 
           
           Circle[{$CellContext`Ax$, $CellContext`Ay$}, $CellContext`L$/1.5, {
            Pi/2 - $CellContext`phi$, Pi/2}], 
           
           Arrow[{{$CellContext`Ax$ + ($CellContext`L$/1.5) 
               Cos[Pi/2 - $CellContext`phi$/
                 5], $CellContext`Ay$ + ($CellContext`L$/1.5) 
               Sin[Pi/2 - $CellContext`phi$/
                 5]}, {$CellContext`Ax$, $CellContext`Ay$ + $CellContext`L$/
               1.5}}], 
           
           Arrow[{{$CellContext`Ax$ + ($CellContext`L$/1.5) 
               Cos[Pi/2 - $CellContext`phi$ + $CellContext`phi$/
                  5], $CellContext`Ay$ + ($CellContext`L$/1.5) 
               Sin[Pi/2 - $CellContext`phi$ + $CellContext`phi$/
                  5]}, {$CellContext`Ax$ + ($CellContext`L$/1.5) 
               Cos[
                Pi/2 - $CellContext`phi$], $CellContext`Ay$ + \
($CellContext`L$/1.5) Sin[Pi/2 - $CellContext`phi$]}}], 
           If[Abs[$CellContext`phi$] > 0, 
            Text[
            "\!\(\*\nStyleBox[FractionBox[\"\[Pi]\", \"2\"],\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"-\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"(\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Alpha]\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"+\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Beta]\",\nFontFamily->\
\"Times New Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\
\)\!\(\*\nStyleBox[\")\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", {$CellContext`Ax$ + \
($CellContext`L$/2) Cos[Pi/4], $CellContext`Ay$ + ($CellContext`L$/2) 
               Sin[Pi/4]}], 
            Text[
            "\!\(\*\nStyleBox[FractionBox[\"\[Pi]\", \"2\"],\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", {$CellContext`Ax$ + ($CellContext`L$/2) 
               Cos[Pi/4], $CellContext`Ay$ + ($CellContext`L$/2) Sin[Pi/4]}]], 
           If[Abs[$CellContext`phi$] > 0, 
            Text[
            "\!\(\*\nStyleBox[\"\[Alpha]\",\nFontFamily->\"Times New Roman\",\
\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", \
{$CellContext`Ax$ + ($CellContext`L$/1.4) 
               Cos[$CellContext`phi$/2], $CellContext`Ay$ + ($CellContext`L$/
                1.4) Sin[$CellContext`phi$/2]}]], 
           If[Abs[$CellContext`phi$] > 0, 
            Text[
            "\!\(\*\nStyleBox[\"\[Beta]\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", {$CellContext`Ax$ + \
($CellContext`L$/1.4) 
               Cos[Pi/2 - $CellContext`phi$/
                 2], $CellContext`Ay$ + ($CellContext`L$/1.4) 
               Sin[Pi/2 - $CellContext`phi$/2]}]]}; $CellContext`dwf7$ = {
           Opacity[1 - $CellContext`opa2$$], Red, 
           Thickness[0.008], 
           Arrowheads[0.06], 
           
           Arrow[{{$CellContext`Ax$ + ($CellContext`L$/
                 2 + ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
               Cos[$CellContext`phi$], $CellContext`Ay$ + ($CellContext`L$/
                 2 + ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
               Sin[$CellContext`phi$] - $CellContext`W$/
              20}, {$CellContext`Ax$ + ($CellContext`L$/
                 2 - ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
               Cos[$CellContext`phi$], $CellContext`Ay$ + ($CellContext`L$/
                 2 - ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
               Sin[$CellContext`phi$] - $CellContext`W$/20}}], 
           
           Arrow[{{$CellContext`Ax$ + ($CellContext`L$/
                 2 + ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
               Cos[Pi/2 - $CellContext`phi$] - $CellContext`W$/
              20, $CellContext`Ay$ + ($CellContext`L$/
                 2 + ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
               Sin[Pi/2 - $CellContext`phi$]}, {$CellContext`Ax$ + \
($CellContext`L$/2 - ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
               Cos[Pi/2 - $CellContext`phi$] - $CellContext`W$/
              20, $CellContext`Ay$ + ($CellContext`L$/
                 2 - ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
               Sin[Pi/2 - $CellContext`phi$]}}], 
           
           Arrow[{{$CellContext`Cx$ - ($CellContext`L$/
                2 + ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
              Cos[Pi/2 - $CellContext`phi$] + $CellContext`W$/
               20, $CellContext`Cy$ - ($CellContext`L$/
                2 + ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
              Sin[Pi/2 - $CellContext`phi$]}, {$CellContext`Cx$ - \
($CellContext`L$/2 - ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
              Cos[Pi/2 - $CellContext`phi$] + $CellContext`W$/
               20, $CellContext`Cy$ - ($CellContext`L$/
                2 - ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
              Sin[Pi/2 - $CellContext`phi$]}}], 
           
           Arrow[{{$CellContext`Cx$ - ($CellContext`L$/
                2 + ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
              Cos[$CellContext`phi$], $CellContext`Cy$ - ($CellContext`L$/
                2 + ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
              Sin[$CellContext`phi$] + $CellContext`W$/
               20}, {$CellContext`Cx$ - ($CellContext`L$/
                2 - ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
              Cos[$CellContext`phi$], $CellContext`Cy$ - ($CellContext`L$/
                2 - ($CellContext`phi$ (2/Pi)) $CellContext`L$) 
              Sin[$CellContext`phi$] + $CellContext`W$/20}}], 
           If[Abs[$CellContext`phi$] > 0, 
            Text[
            "\!\(\*\nStyleBox[SubscriptBox[\"V\", \"x\"],\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\"]\)", \
{($CellContext`Ax$ + $CellContext`Bx$)/
              2, ($CellContext`Ay$ + $CellContext`By$)/2 - $CellContext`W$/
              8}]], 
           If[Abs[$CellContext`phi$] > 0, 
            Text[
            "\!\(\*\nStyleBox[SubscriptBox[\"V\", \"y\"],\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\"]\)", \
{($CellContext`Ax$ + $CellContext`Dx$)/2 - $CellContext`W$/
              8, ($CellContext`Ay$ + $CellContext`Dy$)/2}]], 
           If[Abs[$CellContext`phi$] > 0, 
            Text[
            "\!\(\*\nStyleBox[SubscriptBox[\"V\", \"x\"],\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\"]\)", \
{($CellContext`Cx$ + $CellContext`Dx$)/
              2, ($CellContext`Cy$ + $CellContext`Dy$)/2 + $CellContext`W$/
               8}]], 
           If[Abs[$CellContext`phi$] > 0, 
            Text[
            "\!\(\*\nStyleBox[SubscriptBox[\"V\", \"y\"],\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\"]\)", \
{($CellContext`Bx$ + $CellContext`Cx$)/2 + $CellContext`W$/
               8, ($CellContext`By$ + $CellContext`Cy$)/
              2}]]}; $CellContext`dwf8$ = {
           Opacity[1 - $CellContext`opa2$$], 
           Thickness[0.001], 
           Arrowheads[0.02], 
           
           Line[{{(-$CellContext`L$)/2, $CellContext`L$/
              2}, {(-$CellContext`L$)/
              2, $CellContext`L$/2 + $CellContext`L$/8}}], 
           
           Line[{{$CellContext`L$/2, $CellContext`L$/2}, {$CellContext`L$/
              2, $CellContext`L$/2 + $CellContext`L$/8}}], 
           
           Arrow[{{(-$CellContext`L$)/
              2, $CellContext`L$/2 + $CellContext`L$/9}, {$CellContext`L$/
              2, $CellContext`L$/2 + $CellContext`L$/9}}], 
           
           Arrow[{{$CellContext`L$/
              2, $CellContext`L$/2 + $CellContext`L$/9}, {(-$CellContext`L$)/
              2, $CellContext`L$/2 + $CellContext`L$/9}}], 
           Text[
           "\!\(\*\nStyleBox[SubscriptBox[\"l\", \"x\"],\nFontFamily->\"Times \
New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", {
            0, $CellContext`L$/2 + $CellContext`L$/6}], 
           
           Line[{{$CellContext`L$/2, $CellContext`L$/
              2}, {$CellContext`L$/2 + $CellContext`L$/8, $CellContext`L$/
              2}}], 
           
           Line[{{$CellContext`L$/2, (-$CellContext`L$)/
              2}, {$CellContext`L$/2 + $CellContext`L$/8, (-$CellContext`L$)/
              2}}], 
           
           Arrow[{{$CellContext`L$/2 + $CellContext`L$/8, $CellContext`L$/
              2}, {$CellContext`L$/2 + $CellContext`L$/8, (-$CellContext`L$)/
              2}}], 
           
           Arrow[{{$CellContext`L$/2 + $CellContext`L$/8, (-$CellContext`L$)/
              2}, {$CellContext`L$/2 + $CellContext`L$/8, $CellContext`L$/
              2}}], 
           Text[
           "\!\(\*\nStyleBox[SubscriptBox[\"l\", \"y\"],\nFontFamily->\"Times \
New Roman\",\nFontSize->14,\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", {$CellContext`L$/2 + $CellContext`L$/5, 
             0}], 
           
           Arrow[{{(-$CellContext`L$)/2, $CellContext`L$/
              2}, {$CellContext`Dx$, $CellContext`Dy$}}], 
           
           Arrow[{{$CellContext`Dx$, $CellContext`Dy$}, {(-$CellContext`L$)/
              2, $CellContext`L$/2}}], 
           If[Abs[$CellContext`phi$] > 0, 
            If[$CellContext`phi$ > 0, 
             
             Circle[{((-$CellContext`L$)/2 + $CellContext`Dx$)/
                2 - $CellContext`L$/3, ($CellContext`L$/2 + $CellContext`Dy$)/
               2}, $CellContext`L$/3, {0, Pi/2}], 
             
             Circle[{((-$CellContext`L$)/2 + $CellContext`Dx$)/
                2 + $CellContext`L$/3, ($CellContext`L$/2 + $CellContext`Dy$)/
               2}, $CellContext`L$/3, {-Pi, (-3) (Pi/2)}]]], 
           If[Abs[$CellContext`phi$] > 0, 
            If[$CellContext`phi$ > 0, 
             Text[
             "\!\(\*\nStyleBox[\"\[CapitalDelta]u\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", \
{((-$CellContext`L$)/2 + $CellContext`Dx$)/2 - $CellContext`L$/
               3 - $CellContext`L$/
               16, ($CellContext`L$/2 + $CellContext`Dy$)/2 + $CellContext`L$/
                3}], 
             Text[
             "\!\(\*\nStyleBox[\"\[CapitalDelta]u\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", \
{((-$CellContext`L$)/2 + $CellContext`Dx$)/2 + $CellContext`L$/
                3 + $CellContext`L$/
                16, ($CellContext`L$/2 + $CellContext`Dy$)/
                2 + $CellContext`L$/3}]]], 
           
           Arrow[{{$CellContext`L$/2, (-$CellContext`L$)/
              2}, {$CellContext`Bx$, $CellContext`By$}}], 
           
           Arrow[{{$CellContext`Bx$, $CellContext`By$}, {$CellContext`L$/
              2, (-$CellContext`L$)/2}}], 
           If[Abs[$CellContext`phi$] > 0, 
            If[$CellContext`phi$ > 0, 
             
             Circle[{($CellContext`L$/2 + $CellContext`Bx$)/
               2, ((-$CellContext`L$)/2 + $CellContext`By$)/
                2 - $CellContext`L$/3}, $CellContext`L$/3, {0, Pi/2}], 
             
             Circle[{($CellContext`L$/2 + $CellContext`Bx$)/
               2, ((-$CellContext`L$)/2 + $CellContext`By$)/
                2 + $CellContext`L$/3}, $CellContext`L$/3, {(-Pi)/2, 0}]]], 
           If[Abs[$CellContext`phi$] > 0, 
            If[$CellContext`phi$ > 0, 
             Text[
             "\!\(\*\nStyleBox[\"\[CapitalDelta]v\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {($CellContext`L$/
                  2 + $CellContext`Bx$)/2 + $CellContext`L$/
                3, ((-$CellContext`L$)/2 + $CellContext`By$)/
                2 - $CellContext`L$/3 - $CellContext`L$/16}], 
             Text[
             "\!\(\*\nStyleBox[\"\[CapitalDelta]v\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {($CellContext`L$/
                  2 + $CellContext`Bx$)/2 + $CellContext`L$/
                3, ((-$CellContext`L$)/2 + $CellContext`By$)/
                2 + $CellContext`L$/3 + $CellContext`L$/
                16}]]]}; $CellContext`dw1$ = 
         Graphics[{$CellContext`dwf0$, $CellContext`dwf1$, \
$CellContext`dwf2$, $CellContext`dwf3$, $CellContext`dwf4$, \
$CellContext`dwf5$, $CellContext`dwf6$, $CellContext`dwf7$, \
$CellContext`dwf8$}, 
           PlotRange -> {{(-0.78) $CellContext`size$, 
              0.78 $CellContext`size$}, {(-0.77) $CellContext`size$, 
              0.77 $CellContext`size$}}, ImageSize -> 280, Frame -> False]; 
        Show[$CellContext`dw1$]], 
      "Specifications" :> {{{$CellContext`opa2$$, 1, 
          Row[{"Types of Strain", 
            Spacer[51]}]}, {1 -> "Normal", 0 -> "Shear"}, ControlType -> 
         RadioButton, ControlPlacement -> 1}, {{$CellContext`P$$, 0, 
          Row[{"Loading P", 
            Spacer[80]}]}, -5, 5, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 2}, {{$CellContext`V$$, 0, 
          Row[{"Loading V", 
            Spacer[79]}]}, -5, 5, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 3}, 
        Grid[{{
           Manipulate`Place[1]}, {
           PaneSelector[{1 -> Column[{
                Manipulate`Place[2]}], 0 -> Column[{
                Manipulate`Place[3]}]}, 
            Dynamic[$CellContext`opa2$$]]}, {
           Row[{
             Spacer[10], 
             Dynamic[
              
              If[$CellContext`opa2$$ == 
               1, $CellContext`temp1, $CellContext`temp2]]}]}, {
           Row[{
             Spacer[10], 
             Dynamic[
              If[$CellContext`opa2$$ < 1, $CellContext`temp3, 
               Invisible[$CellContext`temp3]]]}]}, {
           Row[{
             Spacer[10], 
             Dynamic[
              If[$CellContext`opa2$$ < 1, $CellContext`temp4, 
               Invisible[$CellContext`temp4]]]}]}, {
           Row[{
             Spacer[10], 
             Dynamic[
              If[$CellContext`opa2$$ < 1, $CellContext`temp5, 
               Invisible[$CellContext`temp5]]]}]}}, Alignment -> Left, 
         Spacings -> {Automatic, 1.5}]}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{969., {256., 265.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center,
 ExpressionUUID -> "466855ae-5fc3-49a2-b06e-7104a49c8f6e"]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.55 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, WindowSize -> {775, 872}, 
  WindowMargins -> {{0, Automatic}, {Automatic, 0}}, FrontEndVersion -> 
  "11.0 for Microsoft Windows (64-bit) (July 28, 2016)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 268, 8, 237, "Title"],
Cell[1757, 45, 1087, 18, 284, "Text"],
Cell[2847, 65, 57010, 1002, 546, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature 1wTgrwXdy4XtnA1yI9T83oUr *)
